import React from "react";
import { connect } from "react-redux";
import { developer } from "../../redux/actions";

export const Dialog = ({ dialog, setDialog, uselessProps }) => {
  const [boxAnimation, setBoxAnimation] = React.useState(false);
  const { text, type, accept } = dialog;

  React.useEffect(() => {
    setTimeout(() => {
      setBoxAnimation(true);
    }, 200);

    return () => {
      setBoxAnimation(false);
    };
  }, []);

  const exit = React.useCallback(
    (e) => {
      setDialog({ ...dialog, open: !dialog.open });
      e.stopPropagation();
    },
    [dialog, setDialog]
  );

  const acceptFunc = React.useCallback(() => {
    setDialog({ ...dialog, open: !dialog.open });
    accept();
  }, [dialog, setDialog, accept]);

  return (
    <div
      className="w-screen  h-full fixed top-0 right-0 bg-gray-500 bg-opacity-10 backdrop-filter backdrop-blur-lg flex justify-center items-center"
      style={{ zIndex: 70 }}
      onClick={(e) => exit(e)}
    >
      <div
        className={`flex flex-col items-center bg-white dark:bg-black dark:bg-opacity-30 backdrop-filter backdrop-blur-xl rounded-md p-5 transition-all transform shadow-2xl ${
          boxAnimation ? "scale-100" : "scale-0"
        }`}
        style={{ minWidth: 300 }}
        onClick={(e) => e.stopPropagation()}
      >
        {/* {type === "confirm" && (
          <div className="w-full flex justify-end text-sm text-bla">exit</div>
        )} */}
        <p
          className={`text-tiny text-gray70 dark:text-white w-full mb-8 leading-7`}
        >
          {text}
        </p>
        {type === "confirm" && (
          <div className="flex  gap-4 w-full">
            <button
              className="py-2.5 w-1/2 shadow-md rounded-sm bg-blueArtyClickDeepSky text-white"
              onClick={() => acceptFunc()}
            >
              باشه
            </button>
            <button
              className="py-2.5 w-1/2 shadow-md rounded-sm bg-redRossoCorsa text-white"
              onClick={() => setDialog({ ...dialog, open: !dialog.open })}
            >
              بیخیال
            </button>
          </div>
        )}
        {type === "alert" && (
          <div className="flex  gap-4 w-full">
            <button
              className="py-2.5 w-full shadow-md rounded-sm bg-blueArtyClickDeepSky text-white"
              onClick={() => setDialog({ ...dialog, open: !dialog.open })}
            >
              باشه
            </button>
          </div>
        )}
      </div>
    </div>
  );
};

const mapStateToProps = (state) => ({
  dialog: state.developer.dialog,
});

const mapDispatchToProps = {
  setDialog: developer.setDialog,
};

export default connect(mapStateToProps, mapDispatchToProps)(Dialog);
