import React from "react";
import { connect } from "react-redux";
import { developer } from "../../redux/actions";

// components
import Graphic from "./layouts/Graphic";
import Features from "../Home/layouts/Features";
import Form from "../Home/layouts/Form";
import Footer from "../../components/Footer";
import Comments from "./layouts/Comments";

//assets
import conditionImage from "../Home/layouts/Features/assets/Condition.svg";
import dataSavingImage from "../Home/layouts/Features/assets/DataSaving.svg";
import interactiveImage from "../Home/layouts/Features/assets/interactive.svg";
import responsiveImage from "../Home/layouts/Features/assets/responsive.svg";
import moneyGainImage from "../Home/layouts/Features/assets/moneyGain.svg";
import multipleStoryImage from "../Home/layouts/Features/assets/multipleStory.svg";
import specialApplicationImage from "../Home/layouts/Features/assets/specialApplication.svg";
import efficientlyContentImage from "../Home/layouts/Features/assets/efficientlyContent.svg";

export const FeaturesPage = ({
  device,
  setHeaderOptions,
  isDesktop,
  uselessProps,
}) => {
  React.useEffect(() => {
    if (isDesktop) {
      setHeaderOptions({ shown: true });
    }
  }, []);

  const features = React.useMemo(() => {
    return [
      {
        title: "امکان مشاهده در تلفن همراه و دسکتاپ",
        description:
          "فرق نمی‌کند کاربران شما با تلفن‌های همراه یا کامپیوترهای شخصی خود وارد حسابشان شوند، دسترسی از هر مکان و زمانی  امکان پذیر است",
        image: responsiveImage,
      },
      {
        title: "امکان ساختن و تعریف چندیت شرط مختلف",
        description:
          "همیشه چند پایان متفاوت بهتر از یک پایان معمولی است. شما می توانید برای محتوای خود چندین شرط مختلف تعریف کنید",
        image: conditionImage,
      },
      {
        title: "امکان تعامل پذیری بالا با کاربران",
        description:
          "رابط و تجربه کاربری بسیار زیبا و آسان  این قابلیت را به کاربران شما می‌دهد تا در سریعترین زمان ممکن با پلتفرم شما ارتباط برقرار کنند",
        image: interactiveImage,
      },
      {
        title: "جمع آوری کلان داده از شرکت کنندگان",
        description:
          "به وسیله ابزارهای مختلفی که در اختیار شما قرار می‌گیرد می توانید اطلاعات کاربران خود را مورد بررسی و ارزیابی قرار دهید",
        image: dataSavingImage,
      },
      {
        title: "قابلیت انتشار چندین داستان بازی",
        description:
          "پلتفرم داستان بازی این قابلیت را دارد تا شما بعنوان ناشر چندین اثر از خودتان یا مجموعه منتشر کنید ",
        image: multipleStoryImage,
      },
      {
        title: "قابلیت انتشار اپلیکیشن اختصاصی",
        description:
          "همیشه چند پایان متفاوت بهتر از یک پایان معمولی است. شما می توانید برای محتوای خود چندین شرط مختلف تعریف کنید ",
        image: specialApplicationImage,
      },
      {
        title: "سیستم جالب درآمد زایی موثر و کارا",
        description:
          "برای هر یک از پروژه‌های خود در داستان بازی اقدام دریافت اشتراک و فروش به صورت هر اپیزود به کاربران یا جامعه هدف خود کنید",
        image: moneyGainImage,
      },
      {
        title: "تولید محتوای خلاقانه و اختصای برای شما",
        description:
          "اگر یک ایده جالب و نوآورانه دارید می توانید از تیم قدرتمند تولید مختوای داستان بازی استفاده  کنید و بقیه کارها رو به ما بسپارید",
        image: efficientlyContentImage,
      },
    ];
  }, [uselessProps]);
  return (
    <main className="flex-1 flex flex-col items-center">
      <Graphic />
      <Features itemsProps={features} />
      <Comments />
      <Form />
      <Footer />
    </main>
  );
};

const mapStateToProps = (state) => ({
  isDesktop: state.developer.device === "desktop",
});

const mapDispatchToProps = {
  setHeaderOptions: developer.setHeaderOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(FeaturesPage);
