import React from "react";
import { connect } from "react-redux";
import TypeAnimation from "react-type-animation";

//assets
import logoImage from "./assets/logo.svg";
import galleryImage from "./assets/gallery.svg";
import voiceImage from "./assets/voice.svg";
import message1Image from "./assets/message1.svg";
import message2Image from "./assets/message2.svg";
import message3Image from "./assets/message3.svg";
import robanImage from "./assets/roban.svg";
import user1Image from "./assets/user1.svg";
import user2Image from "./assets/user2.svg";
import user3Image from "./assets/user3.svg";
import user4Image from "./assets/user4.svg";
import user5Image from "./assets/user5.svg";
import user6Image from "./assets/user6.svg";
import user7Image from "./assets/user7.svg";
import icon1Image from "./assets/icon1.svg";
import icon2Image from "./assets/icon2.svg";
import icon3Image from "./assets/icon3.svg";
import path1Image from "./assets/path1.svg";
import path2Image from "./assets/path2.svg";
import path3Image from "./assets/path3.svg";

export const Graphic = ({ uselessProps }) => {
  const [animationFlags, setAnimationFlags] = React.useState({
    roban: false,
    voice: false,
    gallery: false,
    avatar: false,
    icon: false,
    title: false,
    description: false,
    messages: false,
  });

  const type = React.useMemo(() => {
    return (
      <TypeAnimation
        cursor={true}
        repeat={1}
        sequence={[
          "شاید برای شما هم اتفاق افتاده باشه که یک داستان درجه یک و هیجان انگیز خونده باشید. اما اینجا داستان فرق می‌کنه این بار شما در مرکز اتفاقات هیجان انگیز هستید ...!",
          12000,
          ,
        ]}
        wrapper="p"
        className="text-2x text-primary-1 text-center font-4 w-full transform -translate-y-1/3"
      />
    );
  }, [uselessProps]);

  React.useEffect(() => {
    //roban
    setTimeout(() => {
      setAnimationFlags({ ...animationFlags, roban: true });
    }, 600);

    //icons
    setTimeout(() => {
      setAnimationFlags({ ...animationFlags, icon: true, roban: true });
    }, 1500);

    //title
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
      });
    }, 2500);

    // description
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        description: true,
      });
    }, 3000);

    //messages
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        messages: true,
        description: true,
      });
    }, 3600);

    //gallery
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        messages: true,
        gallery: true,
        description: true,
      });
    }, 4600);

    // voice
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        messages: true,
        gallery: true,
        voice: true,
        description: true,
      });
    }, 5600);

    // image
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        messages: true,
        gallery: true,
        voice: true,
        description: true,
        avatar: true,
      });
    }, 6500);
    //path
    setTimeout(() => {
      setAnimationFlags({
        ...animationFlags,
        icon: true,
        roban: true,
        title: true,
        messages: true,
        gallery: true,
        voice: true,
        description: true,
        avatar: true,
        paths: true,
      });
    }, 7200);
  }, []);

  return (
    <header
      className="w-10/12 flex relative"
      style={{
        height: "calc( 100vh - 100vh / 12)",
      }}
    >
      {/* roban */}
      {animationFlags.roban && (
        <img
          src={robanImage}
          alt="روبان"
          className="absolute top-0 left-1/2 roban origin-left"
        />
      )}

      {/* logo */}
      <img
        src={logoImage}
        alt="لوگو"
        className="absolute origin-bottom-left left-1/2 logo"
      />
      {/* title */}
      <div
        className="flex flex-col absolute left-1/2 transform -translate-x-1/2 gap-10 items-center"
        style={{ top: "calc((100vh - 100vh / 12) / 2.5)" }}
      >
        {animationFlags.title && (
          <>
            <h1 className="font-7 text-10x text-primary-1 text-center title-top-line">
              داستان‌ها با شما
            </h1>
            <h1 className="font-7 text-10x text-primary-1 text-center title-bottom-line">
              حرف می‌زنند
            </h1>
          </>
        )}
        {animationFlags.description && (
          <div
            style={{
              width: "calc(10 / 12 * 100vw / 2.5)",
            }}
          >
            {type}
          </div>
        )}
      </div>
      {/* galleryImage */}
      {animationFlags.gallery && (
        <img
          src={galleryImage}
          alt="گالری"
          className="absolute left-0 gallery z-10"
          style={{
            width: "19.11vw",
            bottom: "calc((100vh - 100vh / 12) / 10)",
          }}
        />
      )}

      {/* voice */}
      {animationFlags.voice && (
        <img
          src={voiceImage}
          alt="وویس"
          className="absolute voice"
          style={{
            width: "16.77vw",
            bottom: "calc((100vh - 100vh / 12) / 10)",
            right: "calc(19.11vw - 1.5vw)",
          }}
        />
      )}

      {animationFlags.messages && (
        <>
          <img
            src={message1Image}
            alt="پیام"
            className="absolute message1 text-right"
            style={{
              width: "18.95vw",
              top: "calc((100vh - 100vh / 12) / 3.5)",
              right: "calc(19.11vw - 1.5vw)",
            }}
          />
          <img
            src={message2Image}
            alt="پیام"
            className="absolute left-0 message2"
            style={{
              width: "19.21vw",
              top: "calc((100vh - 100vh / 12) / 6)",
            }}
          />
          <img
            src={message3Image}
            alt="پیام"
            className="absolute bottom-0 message3"
            style={{
              width: "15.83vw",
              left: "9.66vw",
            }}
          />
        </>
      )}

      <img
        src={user1Image}
        alt="کاربر"
        className={`absolute right-0 transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "5.20vw",
          top: "calc((100vh - 100vh / 12) / 20)",
        }}
      />
      {/* user2 */}
      <img
        src={user2Image}
        alt="کاربر"
        className={`absolute transform transition-all duration-700 -translate-x-1/2 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "5.20vw",
          top: "calc((100vh - 100vh / 12) / 18)",
          left: "calc(19.11vw / 2)",
        }}
      />
      {/* user3 */}
      <img
        src={user3Image}
        alt="کاربر"
        className={`absolute transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100 " : "scale-0"
        }`}
        style={{
          width: "8.07vw",
          top: "calc((100vh - 100vh / 12) / 7)",
          left: "22.11vw",
        }}
      />
      {/* user4 */}
      <img
        src={user4Image}
        alt="کاربر"
        className={`absolute transform -translate-x-full translate-y-1/4 transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "5.20vw",
          top: "calc((100vh - 100vh / 12) / 2.5)",
          left: "calc(19.11vw / 2.4)",
        }}
      />
      {/* user5 */}
      <img
        src={user5Image}
        alt="کاربر"
        className={`absolute transform -translate-y-full translate-x-full transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "6.71vw",
          bottom: "calc((100vh - 100vh / 12) / 6)",
          right: "calc(19.11vw)",
        }}
      />
      {/* user6 */}
      <img
        src={user6Image}
        alt="کاربر"
        className={`absolute bottom-0 transform  -translate-x-full translate-y-1/3 transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "4.32vw",
          left: "calc(19.11vw)",
        }}
      />
      {/* user7 */}
      <img
        src={user7Image}
        alt="کاربر"
        className={`absolute bottom-0 transform translate-x-full translate-y-1/2 transition-all duration-700 animate-pulse ${
          animationFlags.avatar ? "scale-100" : "scale-0"
        }`}
        style={{
          width: "7.18vw",
          right: "calc(19.11vw / 1.5)",
        }}
      />

      {animationFlags.icon && (
        <>
          {/* icon1 */}
          <img
            src={icon1Image}
            alt="آیکن"
            className="absolute right-0 icons"
            style={{
              width: "10.72vw",
              top: "calc((100vh - 100vh / 12) / 40)",
              right: "16.95vw",
            }}
          />
          {/* icon2 */}
          <img
            src={icon2Image}
            alt="آیکن"
            className="absolute right-0 icons"
            style={{
              width: "2.70vw",
              top: "calc((100vh - 100vh / 12) / 2.9)",
              right: "24vw",
            }}
          />
          {/* icon3 */}
          <img
            src={icon3Image}
            alt="آیکن"
            className="absolute left-0 icons"
            style={{
              width: "4.32vw",
              left: "15.80vw",
              top: "calc((100vh - 100vh / 12) / 1.75)",
            }}
          />
        </>
      )}

      {animationFlags.paths && (
        <>
          <img
            src={path1Image}
            className="absolute"
            alt="مسیر"
            style={{
              width: "25.78vw",
              left: "-1vw",
              top: "calc((100vh - 100vh / 12) / 4)",
            }}
          />
          <img
            src={path2Image}
            className="absolute"
            alt="مسیر"
            style={{
              width: "20.57vw",
              left: "50.3vw",
              top: "calc((100vh - 100vh / 12) / 2.2)",
            }}
          />
          <img
            src={path3Image}
            className="absolute"
            alt="مسیر"
            style={{
              width: "64.89vw",
              left: "-1vw",
              top: "calc((100vh - 100vh / 12) / 1.90)",
            }}
          />
        </>
      )}
    </header>
  );
};

const mapStateToProps = (state) => ({});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(Graphic);
